@@ -14,12 +14,13 @@ class WebServerValidator(metaclass=Singleton):
             self.request_handler.send(
                 "GET",
                 timeout=20,
-                url="{}://{}:{}".format(
-                    host.protocol,
+                url="https://{}".format(
+                    #host.protocol,
                     host.target,
-                    host.port
+                #    host.port
                 )
             )
             return True
-        except RequestHandlerException:
+        except RequestHandlerException as e:
+            print("ERROR ", e)
             raise WebServerValidatorException
